@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2024 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@ import (
 type ErrLineErr struct {
 	err      error
 	file     string
-	line     int
 	function string
+	line     int
 }
 
 func (err ErrLineErr) Error() string {
@@ -50,5 +50,10 @@ func ErrLine(err error) error {
 		errLine.function = frame.Function + "," + errLine.function
 		return errLine
 	}
-	return ErrLineErr{err, frame.File, frame.Line, frame.Function}
+	return ErrLineErr{
+		err:      err,
+		file:     frame.File,
+		line:     frame.Line,
+		function: frame.Function,
+	}
 }
