@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2024 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -112,9 +112,7 @@ func isOOD(tgt *Tgt, level int, seen map[string]*Tgt) (bool, error) {
 				OODCache[tgt.rel] = ood
 				return ood, nil
 			}
-			if err != nil {
-				return true, TgtError{tgt, ErrLine(err)}
-			}
+			return true, TgtError{tgt, ErrLine(err)}
 		}
 		DepCache[tgt.rel] = dep
 	}
@@ -170,11 +168,13 @@ func isOOD(tgt *Tgt, level int, seen map[string]*Tgt) (bool, error) {
 			tracef(CDebug, "ood: %s%s -> %s: same inode", indent, tgt, ifchange.tgt)
 		} else {
 			tracef(CDebug, "ood: %s%s -> %s: inode differs", indent, tgt, ifchange.tgt)
-			fd, err := os.Open(ifchange.tgt.a)
+			var fd *os.File
+			fd, err = os.Open(ifchange.tgt.a)
 			if err != nil {
 				return ood, TgtError{tgt, ErrLine(err)}
 			}
-			hsh, err := fileHash(fd)
+			var hsh Hash
+			hsh, err = fileHash(fd)
 			fd.Close()
 			if err != nil {
 				return ood, TgtError{tgt, ErrLine(err)}
@@ -198,7 +198,7 @@ func isOOD(tgt *Tgt, level int, seen map[string]*Tgt) (bool, error) {
 			continue
 		}
 
-		if _, ok := seen[ifchange.tgt.rel]; ok {
+		if _, exists := seen[ifchange.tgt.rel]; exists {
 			tracef(CDebug, "ood: %s%s -> %s: was always built", indent, tgt, ifchange.tgt)
 			OODCache[ifchange.tgt.rel] = false
 			continue
@@ -248,7 +248,7 @@ RecordOODTgt:
 	if _, err = FdOODTgts.Seek(0, io.SeekEnd); err != nil {
 		log.Fatal(err)
 	}
-	if _, err := FdOODTgts.WriteString(tgt.a + "\x00"); err != nil {
+	if _, err = FdOODTgts.WriteString(tgt.a + "\x00"); err != nil {
 		log.Fatal(err)
 	}
 	flock.Type = unix.F_UNLCK
