@@ -1,5 +1,5 @@
 // goredo -- djb's redo implementation on pure Go
-// Copyright (C) 2020-2024 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2020-2025 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -36,8 +36,9 @@ import (
 	"syscall"
 	"time"
 
-	"go.cypherpunks.ru/recfile"
-	"go.cypherpunks.ru/tai64n/v2"
+	"github.com/google/uuid"
+	"go.cypherpunks.su/recfile/v2"
+	"go.cypherpunks.su/tai64n/v4"
 	"golang.org/x/sys/unix"
 )
 
@@ -99,11 +100,11 @@ func init() {
 }
 
 type RunError struct {
+	Err      error
 	Tgt      *Tgt
-	DoFile   string
 	Started  *time.Time
 	Finished *time.Time
-	Err      error
+	DoFile   string
 }
 
 func (e *RunError) Name() string {
@@ -127,7 +128,7 @@ func mkdirs(pth string) error {
 	if FileExists(pth) {
 		return nil
 	}
-	return os.MkdirAll(pth, os.FileMode(0777))
+	return os.MkdirAll(pth, os.FileMode(0o777))
 }
 
 func isModified(dep *Dep, tgt *Tgt) (
@@ -186,7 +187,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 	fdLock, err := os.OpenFile(
 		path.Join(redoDir, tgtT+LockSuffix),
 		os.O_WRONLY|os.O_TRUNC|os.O_CREATE,
-		os.FileMode(0666),
+		os.FileMode(0o666),
 	)
 	if err != nil {
 		return TgtError{tgt, ErrLine(err)}
@@ -198,7 +199,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 	lockRelease := func() {
 		tracef(CLock, "LOCK_UN: %s", fdLock.Name())
 		flock.Type = unix.F_UNLCK
-		if err := unix.FcntlFlock(fdLock.Fd(), unix.F_SETLK, &flock); err != nil {
+		if err = unix.FcntlFlock(fdLock.Fd(), unix.F_SETLK, &flock); err != nil {
 			log.Fatalln(err, fdLock.Name())
 		}
 		fdLock.Close()
@@ -225,7 +226,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 			defer Jobs.Done()
 			tracef(CLock, "LOCK_EX: %s", fdLock.Name())
 		LockAgain:
-			if err := unix.FcntlFlock(fdLock.Fd(), unix.F_SETLKW, &flock); err != nil {
+			if err = unix.FcntlFlock(fdLock.Fd(), unix.F_SETLKW, &flock); err != nil {
 				if errors.Is(err, unix.EDEADLK) {
 					time.Sleep(10 * time.Millisecond)
 					goto LockAgain
@@ -239,7 +240,8 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 					log.Fatal(err)
 				}
 			}
-			build, err := depBuildRead(tgt.dep)
+			var build uuid.UUID
+			build, err = depBuildRead(tgt.dep)
 			if err == nil {
 				if build != BuildUUID {
 					err = errors.New("was not built: build differs")
@@ -328,7 +330,9 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 	runErr := RunError{Tgt: tgt}
 	// Determine basename and DIRPREFIX
 	{
-		doFileRelPath, upLevels, err := findDo(fdDepW, fdDep.Name(), tgtH, tgtT)
+		var doFileRelPath string
+		var upLevels int
+		doFileRelPath, upLevels, err = findDo(fdDepW, fdDep.Name(), tgtH, tgtT)
 		if err != nil {
 			cleanup()
 			return TgtError{tgt, ErrLine(err)}
@@ -355,7 +359,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		}
 	}
 
-	if err = depWrite(fdDepW, fdDep.Name(), tgtH, doFile, ""); err != nil {
+	if err = depWrite(fdDepW, fdDep.Name(), tgtH, doFile, HashNull); err != nil {
 		cleanup()
 		return TgtError{tgt, ErrLine(err)}
 	}
@@ -441,7 +445,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		fdStderr, err = os.OpenFile(
 			path.Join(redoDir, tgtT+LogSuffix),
 			os.O_WRONLY|os.O_CREATE|os.O_TRUNC,
-			os.FileMode(0666),
+			os.FileMode(0o666),
 		)
 		if err != nil {
 			cleanup()
@@ -480,7 +484,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		var exitErr *exec.ExitError
 		started := time.Now()
 		runErr.Started = &started
-		fdStdout, err = os.OpenFile(fdStdout.Name(), os.O_RDWR, os.FileMode(0666))
+		fdStdout, err = os.OpenFile(fdStdout.Name(), os.O_RDWR, os.FileMode(0o666))
 		if err != nil {
 			if fdStderr != nil {
 				fdStderr.Close()
@@ -490,7 +494,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 			return
 		}
 		cmd.Stdout = fdStdout
-		fdDep, err = os.OpenFile(fdDep.Name(), os.O_WRONLY|os.O_APPEND, os.FileMode(0666))
+		fdDep, err = os.OpenFile(fdDep.Name(), os.O_WRONLY|os.O_APPEND, os.FileMode(0o666))
 		if err != nil {
 			if fdStderr != nil {
 				fdStderr.Close()
@@ -518,7 +522,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 				if fdStderr, err = os.OpenFile(
 					logRecPath,
 					os.O_WRONLY|os.O_CREATE|os.O_TRUNC,
-					os.FileMode(0666),
+					os.FileMode(0o666),
 				); err == nil {
 					fields := []recfile.Field{
 						{Name: "Build", Value: BuildUUID.String()},
@@ -530,14 +534,14 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 							Name: "PID", Value: strconv.Itoa(cmd.Process.Pid),
 						})
 					}
-					ts := new(tai64n.TAI64N)
+					var ts tai64n.TAI64N
 					ts.FromTime(started)
 					fields = append(fields,
-						recfile.Field{Name: "Started", Value: tai64n.Encode(ts[:])},
+						recfile.Field{Name: "Started", Value: ts.Encode()},
 					)
 					ts.FromTime(finished)
 					fields = append(fields,
-						recfile.Field{Name: "Finished", Value: tai64n.Encode(ts[:])})
+						recfile.Field{Name: "Finished", Value: ts.Encode()})
 					fields = append(fields, recfile.Field{
 						Name:  "Duration",
 						Value: strconv.FormatInt(finished.Sub(started).Nanoseconds(), 10),
@@ -623,7 +627,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		go func() {
 			scanner := bufio.NewScanner(stderr)
 			var line string
-			ts := new(tai64n.TAI64N)
+			var ts tai64n.TAI64N
 			for scanner.Scan() {
 				line = scanner.Text()
 				if strings.HasPrefix(line, childStderrPrefix) {
@@ -637,7 +641,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 				}
 				if fdStderr != nil {
 					ts.FromTime(time.Now())
-					fmt.Fprintln(fdStderr, tai64n.Encode(ts[:]), line)
+					fmt.Fprintln(fdStderr, ts.Encode(), line)
 				}
 				if StderrSilent {
 					continue
@@ -670,7 +674,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 		}
 
 		// Was $1 touched?
-		if inode, err := inodeFromFileByPath(tgt.a); err == nil {
+		if inode, errInode := inodeFromFileByPath(tgt.a); errInode == nil {
 			if inodePrev == nil {
 				runErr.Err = Err1WasTouched
 				errs <- runErr
@@ -735,7 +739,7 @@ func runScript(tgt *Tgt, errs chan error, forced, traced bool) error {
 			}
 		} else {
 			var hsh Hash
-			if hshPrev != "" {
+			if hshPrev != HashNull {
 				_, err = fd.Seek(0, io.SeekStart)
 				if err != nil {
 					err = ErrLine(err)
